@@ -400,7 +400,11 @@ IOReturn IOFWWriteQuadCommand::execute()
 	{
         // Update nodeID and generation
         fDevice->getNodeIDGeneration( fGeneration, fNodeID );
-		fSpeed = fControl->FWSpeed( fNodeID );    
+		fSpeed = fControl->FWSpeed( fNodeID );
+		if( fMembers->fMaxSpeed < fSpeed )
+		{
+			fSpeed = fMembers->fMaxSpeed;
+		}
     }
 
     fPackSize = fSize;
