@@ -51,6 +51,7 @@ class IOFWAddressSpace;
 class IOFWPseudoAddressSpace;
 class IOFireWireNub;
 class IOFireWireDevice;
+class IOFireWireDeviceAux;
 class IOFireWireUnit;
 class IODCLProgram;
 class IOLocalConfigDirectory;
@@ -361,6 +362,7 @@ protected:
 	friend class IOFWLocalIsochPort;
 	friend class IOFWCommand;
 	friend class IOFireWireDevice;
+	friend class IOFireWireDeviceAux;
     friend class IOFireWirePCRSpace;
     friend class IOFireWireROMCache;
     friend class IOFWAsyncStreamCommand;
@@ -461,6 +463,9 @@ protected:
 	
 	UInt8						fHopCounts[(kFWMaxNodesPerBus+1)*kFWMaxNodesPerBus];
 
+	bool						fUseHalfSizePackets;
+	bool						fRequestedHalfSizePackets;
+	
 /*! @struct ExpansionData
     @discussion This structure will be used to expand the capablilties of the class in the future.
     */    
@@ -775,7 +780,9 @@ protected:
 public:
 
  	IOReturn clipMaxRec2K(Boolean clipMaxRec );
-
+	void setNodeSpeed( UInt16 nodeAddress, IOFWSpeed speed );
+	void useHalfSizePackets( void );
+	
 private:
     OSMetaClassDeclareReservedUnused(IOFireWireController, 0);
     OSMetaClassDeclareReservedUnused(IOFireWireController, 1);
