@@ -74,6 +74,7 @@ bool IOFireWireDeviceAux::init( IOFireWireDevice * primary )
 	if( success )
 	{
 		fTerminated = false;
+		fMaxSpeed = kFWSpeedMaximum;
 	}
 	
 	return success;
@@ -97,6 +98,21 @@ void IOFireWireDeviceAux::setTerminated( bool terminated )
 	fTerminated = terminated;
 }
 
+// setMaxSpeed
+//
+//
+
+void IOFireWireDeviceAux::setMaxSpeed( IOFWSpeed speed )
+{
+	fPrimary->fControl->closeGate();
+
+	fMaxSpeed = speed;
+	
+	((IOFireWireDevice*)fPrimary)->configureNode();
+
+	fPrimary->fControl->openGate();
+}
+
 // free
 //
 //
@@ -1313,12 +1329,18 @@ bool IOFireWireDevice::matchPropertyTable(OSDictionary * table)
 
 #pragma mark -
 
+// message
+//
+//
+
 IOReturn IOFireWireDevice::message( UInt32 mess, IOService * provider,
                                     void * argument )
 {
     // Propagate bus reset start/end messages
     if( kIOFWMessageServiceIsRequestingClose == mess ) 
     {
+		fDeviceROM->setROMState( IOFireWireROMCache::kROMStateInvalid ) ;
+		
         messageClients( mess );
         return kIOReturnSuccess;
     }
@@ -1328,6 +1350,12 @@ IOReturn IOFireWireDevice::message( UInt32 mess, IOService * provider,
 		messageClients( mess );
 		return kIOReturnSuccess;
 	}
+
+	if( kIOFWMessageTopologyChanged == mess )
+	{
+		messageClients( mess );
+		return kIOReturnSuccess;
+	}
 	    
     return IOService::message(mess, provider, argument );
 }
@@ -1517,17 +1545,48 @@ UInt32 IOFireWireDevice::getNodeFlags( void )
 
 IOReturn IOFireWireDevice::configureNode( void )
 {
+	fControl->closeGate();
+
 	if( fNodeID != kFWBadNodeID )
     {
+		//
 		// handle physical filter configuration
+		//
+		
 		configurePhysicalFilter();
 
+		//
+		// configure retry on ack d
+		//
+		
 		if( fNodeFlags & kIOFWEnableRetryOnAckD )
 		{
 			IOFireWireLink * fwim = fControl->getLink();
 			fwim->setNodeFlags( fNodeID & 0x3f, kIOFWNodeFlagRetryOnAckD );
 		}
+		
+		//
+		// limit speed if necessary
+		//
+		
+		IOFWSpeed currentSpeed = FWSpeed();
+		IOFWSpeed maxSpeed = ((IOFireWireDeviceAux*)fAuxiliary)->fMaxSpeed;
+		if( currentSpeed > maxSpeed )
+		{
+			fControl->setNodeSpeed( fNodeID, maxSpeed );
+		}
+
+		//
+		// tell controller to use half size packets
+		//
+		
+		if( fNodeFlags & kIOFWLimitAsyncPacketSize )
+		{
+			fControl->useHalfSizePackets();
+		}
     }
+
+	fControl->openGate();
 	
 	return kIOReturnSuccess;
 }
